@@ -13,7 +13,7 @@ describe 'designate::keystone::authtoken' do
       it 'configure keystone_authtoken' do
         is_expected.to contain_designate_config('keystone_authtoken/username').with_value('designate')
         is_expected.to contain_designate_config('keystone_authtoken/password').with_value('designate_password')
-        is_expected.to contain_designate_config('keystone_authtoken/auth_url').with_value('http://localhost:35357')
+        is_expected.to contain_designate_config('keystone_authtoken/auth_url').with_value('http://localhost:5000')
         is_expected.to contain_designate_config('keystone_authtoken/project_name').with_value('services')
         is_expected.to contain_designate_config('keystone_authtoken/user_domain_name').with_value('Default')
         is_expected.to contain_designate_config('keystone_authtoken/project_domain_name').with_value('Default')
@@ -25,10 +25,8 @@ describe 'designate::keystone::authtoken' do
         is_expected.to contain_designate_config('keystone_authtoken/cache').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/cafile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('keystone_authtoken/check_revocations_for_cached').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/delay_auth_decision').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/enforce_token_bind').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('keystone_authtoken/hash_algorithms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/http_connect_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/http_request_max_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('keystone_authtoken/include_service_catalog').with_value('<SERVICE DEFAULT>')
@@ -53,7 +51,7 @@ describe 'designate::keystone::authtoken' do
           :www_authenticate_uri                 => 'https://10.0.0.1:9999/',
           :username                             => 'myuser',
           :password                             => 'mypasswd',
-          :auth_url                             => 'https://127.0.0.1:35357',
+          :auth_url                             => 'https://127.0.0.1:5000',
           :project_name                         => 'service_project',
           :user_domain_name                     => 'domainX',
           :project_domain_name                  => 'domainX',
@@ -64,10 +62,8 @@ describe 'designate::keystone::authtoken' do
           :cache                                => 'somevalue',
           :cafile                               => '/opt/stack/data/cafile.pem',
           :certfile                             => 'certfile.crt',
-          :check_revocations_for_cached         => false,
           :delay_auth_decision                  => false,
           :enforce_token_bind                   => 'permissive',
-          :hash_algorithms                      => 'md5',
           :http_connect_timeout                 => '300',
           :http_request_max_retries             => '3',
           :include_service_catalog              => true,
@@ -102,10 +98,8 @@ describe 'designate::keystone::authtoken' do
         is_expected.to contain_designate_config('keystone_authtoken/cache').with_value(params[:cache])
         is_expected.to contain_designate_config('keystone_authtoken/cafile').with_value(params[:cafile])
         is_expected.to contain_designate_config('keystone_authtoken/certfile').with_value(params[:certfile])
-        is_expected.to contain_designate_config('keystone_authtoken/check_revocations_for_cached').with_value(params[:check_revocations_for_cached])
         is_expected.to contain_designate_config('keystone_authtoken/delay_auth_decision').with_value(params[:delay_auth_decision])
         is_expected.to contain_designate_config('keystone_authtoken/enforce_token_bind').with_value(params[:enforce_token_bind])
-        is_expected.to contain_designate_config('keystone_authtoken/hash_algorithms').with_value(params[:hash_algorithms])
         is_expected.to contain_designate_config('keystone_authtoken/http_connect_timeout').with_value(params[:http_connect_timeout])
         is_expected.to contain_designate_config('keystone_authtoken/http_request_max_retries').with_value(params[:http_request_max_retries])
         is_expected.to contain_designate_config('keystone_authtoken/include_service_catalog').with_value(params[:include_service_catalog])
